@@ -2,18 +2,11 @@ package Text::Tradition::Collation::Reading;
 
 use Moose;
 use Moose::Util qw/ does_role apply_all_roles /;
-use Moose::Util::TypeConstraints;
+use Text::Tradition::Datatypes;
 use Text::Tradition::Error;
 use XML::Easy::Syntax qw( $xml10_name_rx $xml10_namestartchar_rx );
 use overload '""' => \&_stringify, 'fallback' => 1;
 
-subtype 'ReadingID',
-	as 'Str',
-	where { $_ =~ /\A$xml10_name_rx\z/ },
-	message { 'Reading ID must be a valid XML attribute string' };
-	
-no Moose::Util::TypeConstraints;
-
 # Enable plugin(s) if available
 eval { with 'Text::Tradition::Morphology'; };
 # Morphology package is not on CPAN, so don't warn of its absence
@@ -104,10 +97,11 @@ has 'text' => (
 	writer => 'alter_text',
 	);
 	
-has 'language' => (
+has 'is_lemma' => (
 	is => 'ro',
-	isa => 'Str',
-	predicate => 'has_language',
+	isa => 'Bool',
+	default => undef,
+	writer => 'make_lemma',
 	);
 	
 has 'is_start' => (
